==> easychart-4.0.5.tar.gz: easychart/js/highcharts-editor.widget.js <==
(function ($, Drupal) {
  'use strict';
  Drupal.behaviors.highchartsEditorWidget = {
    attach: function (context, settings) {
      highed.ready(function () {
        const buttons = once('highed-modal-button', '.highed-imp-button', context);

        $(buttons).each(function(i, el) {
          const configValue = $('#' + $(el).attr('config-target')).val();
          let currentOptions = {};
          let csvValue = $('#' + $(el).attr('csv-target')).val();
          let csv = '';

          if (configValue.length > 0) {
            currentOptions = JSON.parse(configValue);
          }

          if (csvValue.length > 0) {
            const jsonCsv = JSON.parse(csvValue);
            csv = jsonCsv.map(function(d) {
              return d.join(';');
            }).join("\n");
          }

          if (currentOptions.data !== undefined && csv.length === 0) {
            csv = currentOptions.data.csv;
          }

          const modal = highed.ModalEditor(el, {
            defaultChartOptions: currentOptions,
            allowDone: true,
            features: 'import templates customize done',
            importer: {
              options: 'plugins csv json'
            }
          }, function (chart) {
            const json = chart.export.json(true);
            const csv = modal.editor.dataTable.toData();
            $('#' + $(el).attr('config-target')).val(JSON.stringify(json));
            $('#' + $(el).attr('csv-target')).val(JSON.stringify(csv));
          });

          if (csv.length > 0) {
            modal.editor.dataTable.clear();
            modal.editor.dataTable.loadCSV({csv: csv});
          }
        });
      });
    }
  }
})(jQuery, Drupal);

==> easychart-4.0.6.tar.gz: easychart/js/highcharts-editor.widget.js <==
(function ($, Drupal) {
  'use strict';
  Drupal.behaviors.highchartsEditorWidget = {
    attach: function (context, settings) {
      highed.ready(function () {
        const buttons = once('highed-modal-button', '.highed-imp-button', context);

        $(buttons).each(function(i, el) {
          const configValue = $('#' + $(el).attr('config-target')).val();
          let currentOptions = {};
          let csvValue = $('#' + $(el).attr('csv-target')).val();
          let csv = '';

          if (configValue.length > 0) {
            currentOptions = JSON.parse(configValue);
          }

          if (csvValue != 'false' && csvValue !== false && csvValue.length > 0) {
            const jsonCsv = JSON.parse(csvValue);

            if (jsonCsv != 'false' && jsonCsv !== false) {
              csv = jsonCsv.map(function (d) {
                return d.join(';');
              }).join("\n");
            }
          }

          if (currentOptions.data !== undefined && csv.length === 0) {
            csv = currentOptions.data.csv;
          }

          const modal = highed.ModalEditor(el, {
            defaultChartOptions: currentOptions,
            allowDone: true,
            features: 'import templates customize done',
            importer: {
              options: 'plugins csv json'
            }
          }, function (chart) {
            const json = chart.export.json(true);
            const csv = modal.editor.dataTable.toData();
            $('#' + $(el).attr('config-target')).val(JSON.stringify(json));
            $('#' + $(el).attr('csv-target')).val(JSON.stringify(csv));
          });

          if (csv.length > 0) {
            modal.editor.dataTable.clear();
            modal.editor.dataTable.loadCSV({csv: csv});
          }
        });
      });
    }
  }
})(jQuery, Drupal);
